==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/util/EmptyNodeList.h <==
// class gnu.xml.libxmlj.util.EmptyNodeList

// class file dependencies
// @dep_class c6275e17467ad54e gnu_xml_libxmlj_util_EmptyNodeList
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_util_EmptyNodeList_H_
#define _JC_gnu_xml_libxmlj_util_EmptyNodeList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_refs	_jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_nonrefs	_jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$refs	_jc_gnu_xml_libxmlj_util_EmptyNodeList$refs;
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$nonrefs	_jc_gnu_xml_libxmlj_util_EmptyNodeList$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object	_jc_gnu_xml_libxmlj_util_EmptyNodeList$object;

typedef const struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vmethods	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtable	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_EmptyNodeList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *);

// Virtual methods
extern jint _jc_gnu_xml_libxmlj_util_EmptyNodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *);
extern struct _jc_object *_jc_gnu_xml_libxmlj_util_EmptyNodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_util_EmptyNodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_libxmlj_util_EmptyNodeList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *);
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *, jint);
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vmethods	gnu_xml_libxmlj_util_EmptyNodeList;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$refs {
    _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_refs	gnu_xml_libxmlj_util_EmptyNodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_nonrefs	gnu_xml_libxmlj_util_EmptyNodeList;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object {
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype _jc_gnu_xml_libxmlj_util_EmptyNodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_EmptyNodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_EmptyNodeList$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_EmptyNodeList_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/util/EmptyNodeList.h <==
// class gnu.xml.libxmlj.util.EmptyNodeList

// class file dependencies
// @dep_class c6275e17467ad54e gnu_xml_libxmlj_util_EmptyNodeList
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_util_EmptyNodeList_H_
#define _JC_gnu_xml_libxmlj_util_EmptyNodeList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_refs	_jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_nonrefs	_jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$refs	_jc_gnu_xml_libxmlj_util_EmptyNodeList$refs;
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$nonrefs	_jc_gnu_xml_libxmlj_util_EmptyNodeList$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object	_jc_gnu_xml_libxmlj_util_EmptyNodeList$object;

typedef const struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vmethods	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtable	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vtable;
typedef const struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_util_EmptyNodeList$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_xml_libxmlj_util_EmptyNodeList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_libxmlj_util_EmptyNodeList$method$item$768348a8778b0a3e(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_util_EmptyNodeList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_libxmlj_util_EmptyNodeList$method_info$item$768348a8778b0a3e;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*item$768348a8778b0a3e)(_jc_env *, struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vmethods	gnu_xml_libxmlj_util_EmptyNodeList;
};

// Vtype
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$refs {
    _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_refs	gnu_xml_libxmlj_util_EmptyNodeList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_util_EmptyNodeList$sub_nonrefs	gnu_xml_libxmlj_util_EmptyNodeList;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_util_EmptyNodeList$object {
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype	*vtype;
	_jc_gnu_xml_libxmlj_util_EmptyNodeList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_util_EmptyNodeList$vtype _jc_gnu_xml_libxmlj_util_EmptyNodeList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_util_EmptyNodeList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_util_EmptyNodeList$class_object;

#endif	/* _JC_gnu_xml_libxmlj_util_EmptyNodeList_H_ */
